Enum PSR
Source pub enum PSR {
High,
MediumHigh,
Medium,
MediumLow,
Low,
}
Available on crate feature weather only.
Probability of significant rain.
More information about PSR, please refer
hko.gov.hk.
Generates the URI of specified PSR icon, usually an HTTPS link.
Formats the name in simplified Chinese.
See formatting rules.
Examples
ⓘlet name = format!("{val:b}");
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Gets the name of the item.
Gets the description of the item.
The associated error which can be returned from parsing.
Parses a string
s to return a value of this type.
Read more
Formats the name in English.
See formatting rules.
Examples
ⓘlet name = format!("{val:e}");
Formats the description in traditional Chinese.
See formatting rules.
Examples
ⓘlet desc = format!("{val:x}");
Formats the name in traditional Chinese.
See formatting rules.
Examples
ⓘlet name = format!("{val:o}");
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Formats the description in simplified Chinese.
See formatting rules.
Examples
ⓘlet desc = format!("{val:p}");
Formats the description in English.
See formatting rules.
Examples
ⓘlet desc = format!("{val:E}");
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.